package at.xaxa.gamelibraryapp

import android.app.Application
import at.xaxa.gamelibraryapp.data.GameRepository
import at.xaxa.gamelibraryapp.data.db.LibraryDatabase
import at.xaxa.gamelibraryapp.data.remote.GameRemoteService
import kotlinx.serialization.json.Json
import okhttp3.MediaType
import okhttp3.MediaType.Companion.toMediaType
import retrofit2.Retrofit
import retrofit2.converter.kotlinx.serialization.asConverterFactory

class LibraryApplication: Application() {
    val libraryRepository by lazy {
        val retrofit = Retrofit.Builder()
            .baseUrl("https://api.rawg.io/api/") // Only the root URL
            .addConverterFactory(Json { ignoreUnknownKeys = true }
                .asConverterFactory("application/json".toMediaType()))
            .build()

        val gameRemoteService = retrofit.create(GameRemoteService::class.java)

        GameRepository(
            LibraryDatabase.getDatabase(this).libraryDao(),
            gameRemoteService
        )
    }
}