package at.xaxa.gamelibraryapp.ui.Details

import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import at.xaxa.gamelibraryapp.data.GameRepository
import at.xaxa.gamelibraryapp.data.db.LibraryEntity
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

data class GameEditUi(
    val libraryEntity: LibraryEntity = LibraryEntity(0, "", "", "")
)

class DetailsViewModel(private val savedStateHandle: SavedStateHandle, private val gameRepository: GameRepository) : ViewModel() {

    private val gameId: Int = checkNotNull(savedStateHandle["gameId"])

    var editUiState by mutableStateOf(GameEditUi())
        private set

    init {
        viewModelScope.launch {
            val game = withContext(Dispatchers.IO) {
                gameRepository.findGameById(gameId)
            }
            editUiState = GameEditUi(game)
        }
    }

    fun updateGame(libraryEntity: LibraryEntity) {
        editUiState = editUiState.copy(libraryEntity=libraryEntity)
    }

    fun saveLibrary() {
        viewModelScope.launch {
            gameRepository.updateEntry(editUiState.libraryEntity)
        }
    }

}