package at.xaxa.gamelibraryapp.ui

import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import at.xaxa.gamelibraryapp.data.Game
import at.xaxa.gamelibraryapp.data.GameRepository
import at.xaxa.gamelibraryapp.data.db.LibraryEntity
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

data class GameDetailUi(
    val game: LibraryEntity = LibraryEntity(0, "", "", "")
)

class GameDetailsViewModel(savedStateHandle: SavedStateHandle, private val gameRepository: GameRepository): ViewModel() {

    private val gameId: Int = checkNotNull(savedStateHandle["gameId"])

    private val _detailUiState = MutableStateFlow(GameDetailUi())
    val detailUiState = _detailUiState.asStateFlow()

    init {
        viewModelScope.launch {
            val libraryEntity = withContext(Dispatchers.IO) {
                gameRepository.findGameById(gameId)
            }
            _detailUiState.update {
                GameDetailUi(libraryEntity)
            }
        }
    }

}