package at.xaxa.gamelibraryapp.ui.GameList

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import at.xaxa.gamelibraryapp.ui.HorizontalCard

@Composable
fun GameList(modifier: Modifier = Modifier, onCardClick: (Int) -> Unit) {
    var searchText by remember { mutableStateOf("") }

    Column(modifier = modifier) {
        // Search Bar
        OutlinedTextField(
            value = searchText,
            onValueChange = { searchText = it },
            label = { Text("Search games") },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp, vertical = 4.dp)
        )

        // Game List
        LazyColumn(modifier = Modifier.fillMaxSize()) {
            items(16) { index ->
                HorizontalCard(
                    modifier = modifier,
                    title = "Game $index",
                    details = "Details about game $index",
                    imageUrl = "https://media.rawg.io/media/games/b7f/b7ffc4c4776e61eca19d36d3c227f89a.jpg",
                    onClick = {
                        onCardClick(index)
                    }
                )
            }
        }
    }
}
